@@ -29,62 +29,58 @@
 # License with the Debian GNU/Linux or Univention distribution in file
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
-"""
-Univention Update tools.
-"""
+"""Univention Update tools."""
+
+from __future__ import absolute_import, print_function
+
 
-from __future__ import absolute_import
-from __future__ import print_function
 try:
     import univention.debug as ud
 except ImportError:
     import univention.debug2 as ud  # type: ignore
 
 # TODO: Convert to absolute imports only AFTER the unit test has been adopted
-from .commands import (
-    cmd_dist_upgrade,
-    cmd_dist_upgrade_sim,
-    cmd_update,
-)
-from .errors import (
-    UnmetDependencyError,
-    CannotResolveComponentServerError,
-    ConfigurationError,
-    DownloadError,
-    PreconditionError,
-    RequiredComponentError,
-    ProxyError,
-    VerificationError,
-)
-from .repo_url import UcsRepoUrl
+import base64
+import copy
+import errno
+import functools
+import json
+import logging
+import os
+import re
+import socket
+import subprocess
+import sys
+import tempfile
+
+import six
+from six.moves import http_client as httplib, urllib_error, urllib_request as urllib2
+
+from univention.config_registry import ConfigRegistry
 from univention.lib.ucs import UCS_Version
 
-import errno
-import sys
-import re
-import os
-import copy
-from six.moves import http_client as httplib
-import socket
-from univention.config_registry import ConfigRegistry
-from six.moves import urllib_request as urllib2, urllib_error
-import json
-import subprocess
-import tempfile
-import logging
-import functools
-import six
-import base64
+from .commands import cmd_dist_upgrade, cmd_dist_upgrade_sim, cmd_update
+from .errors import (
+    CannotResolveComponentServerError, ConfigurationError, DownloadError, PreconditionError, ProxyError,
+    RequiredComponentError, UnmetDependencyError, VerificationError,
+)
+from .repo_url import UcsRepoUrl
+
+
 try:
-    from typing import Any, AnyStr, Dict, Generator, Iterable, Iterator, List, Optional, Sequence, Set, Text, Tuple, Type, TypeVar, Union  # noqa: F401
+    from typing import (  # noqa: F401
+        Any, AnyStr, Dict, Generator, Iterable, Iterator, List, Optional, Sequence, Set, Text, Tuple, Type, TypeVar,
+        Union,
+    )
+
     from typing_extensions import Literal  # noqa: F401
     _TS = TypeVar("_TS", bound="_UCSServer")
 except ImportError:
     pass
 
 if six.PY2:
-    from new import instancemethod
     from backports.tempfile import TemporaryDirectory
+    from new import instancemethod
 else:
     from tempfile import TemporaryDirectory
 
@@ -131,9 +127,7 @@ def verify_script(script, signature):
 
 
 class _UCSRepo(UCS_Version):
-    """
-    Super class to build URLs for APT repositories.
-    """
+    """Super class to build URLs for APT repositories."""
 
     ARCHS = {'all', 'amd64'}
 
@@ -161,9 +155,7 @@ class _UCSRepo(UCS_Version):
 
     def _format(self, format):
         # type: (str) -> str
-        """
-        Format longest path for directory/file access.
-        """
+        """Format longest path for directory/file access."""
         while True:
             try:
                 return format % self
@@ -245,9 +237,7 @@ class _UCSRepo(UCS_Version):
 
 
 class UCSRepoPool5(_UCSRepo):
-    """
-    APT repository using the debian pool structure (ucs5 and above).
-    """
+    """APT repository using the debian pool structure (ucs5 and above)."""
 
     def __init__(self, release=None, **kwargs):
         # type: (UCS_Version, **Any) -> None
@@ -312,9 +302,7 @@ class UCSRepoPool5(_UCSRepo):
 
 
 class UCSRepoPool(_UCSRepo):
-    """
-    Flat Debian APT repository.
-    """
+    """Flat Debian APT repository."""
 
     def __init__(self, **kw):
         # type: (**Any) -> None
@@ -374,9 +362,7 @@ class UCSRepoPool(_UCSRepo):
 
 
 class UCSRepoPoolNoArch(_UCSRepo):
-    """
-    Flat Debian APT repository without explicit architecture subdirectory.
-    """
+    """Flat Debian APT repository without explicit architecture subdirectory."""
 
     ARCHS = {''}
 
@@ -438,9 +424,7 @@ class UCSRepoPoolNoArch(_UCSRepo):
 
 
 class _UCSServer(object):
-    """
-    Abstrace base class to access UCS compatible update server.
-    """
+    """Abstrace base class to access UCS compatible update server."""
 
     @classmethod
     def load_credentials(self, ucr):
@@ -450,7 +434,6 @@ class _UCSServer(object):
 
         :param ConfigRegistry ucr: An UCR instance.
         """
-        pass
 
     def join(self, rel):
         # type: (str) -> str
@@ -506,14 +489,10 @@ class _UCSServer(object):
 
 
 class UCSHttpServer(_UCSServer):
-    """
-    Access to UCS compatible remote update server.
-    """
+    """Access to UCS compatible remote update server."""
 
     class HTTPHeadHandler(urllib2.BaseHandler):
-        """
-        Handle fallback from HEAD to GET if unimplemented.
-        """
+        """Handle fallback from HEAD to GET if unimplemented."""
 
         def http_error_501(self, req, fp, code, msg, headers):  # httplib.NOT_IMPLEMENTED
             # type: (urllib2.Request, Any, int, str, Dict) -> Any
@@ -558,9 +537,7 @@ class UCSHttpServer(_UCSServer):
     @classmethod
     def reinit(self):
         # type: () -> None
-        """
-        Reload proxy settings and reset failed hosts.
-        """
+        """Reload proxy settings and reset failed hosts."""
         self.proxy_handler = urllib2.ProxyHandler()
         self.opener = urllib2.build_opener(self.head_handler, self.auth_handler, self.proxy_handler)
         self.failed_hosts.clear()
@@ -592,23 +569,19 @@ class UCSHttpServer(_UCSServer):
             username = cfg.pop('username', uuid)
             password = cfg.pop('password', uuid)
             if cfg:
-                self.log.warn('Extra credentials for realm "%s": %r', realm, cfg)
+                self.log.warning('Extra credentials for realm "%s": %r', realm, cfg)
 
             self.password_manager.add_password(realm, uris, username, password)
             self.log.info('Loaded credentials for realm "%s"', realm)
 
     def __str__(self):
         # type: () -> str
-        """
-        URI with credentials.
-        """
+        """URI with credentials."""
         return self.baseurl.private()
 
     def __repr__(self):
         # type: () -> str
-        """
-        Return canonical string representation.
-        """
+        """Return canonical string representation."""
         return '%s(%r, timeout=%r)' % (
             self.__class__.__name__,
             self.baseurl,
@@ -760,9 +733,7 @@ class UCSHttpServer(_UCSServer):
 
 
 class UCSLocalServer(_UCSServer):
-    """
-    Access to UCS compatible local update server.
-    """
+    """Access to UCS compatible local update server."""
 
     def __init__(self, prefix):
         # type: (str) -> None
@@ -783,16 +754,12 @@ class UCSLocalServer(_UCSServer):
 
     def __str__(self):
         # type: () -> str
-        """
-        Absolute file-URI.
-        """
+        """Absolute file-URI."""
         return 'file:///%s' % self.prefix
 
     def __repr__(self):
         # type: () -> str
-        """
-        Return canonical string representation.
-        """
+        """Return canonical string representation."""
         return 'UCSLocalServer(prefix=%r)' % (self.prefix,)
 
     def __add__(self, rel):
@@ -893,7 +860,7 @@ class Component(object):
 
     def __str__(self):
         # type: () -> str
-        return "Component({0.name})".format(self)
+        return "Component({.name})".format(self)
 
     def ucrv(self, key=""):
         # type: (str) -> str
@@ -934,11 +901,11 @@ class Component(object):
 
         :returns: a set of package names.
         """
-        return set((
+        return {
             pkg
             for var in ('defaultpackages', 'defaultpackage')
             for pkg in RE_SPLIT_MULTI.split(self[var])
-        )) - {""}
+        } - {""}
 
     def defaultpackage_installed(self, ignore_invalid_package_names=True):
         # type: (bool) -> Optional[bool]
@@ -1031,7 +998,6 @@ class Component(object):
 
         .. [1] if `repository/online/component/%s/localmirror` is unset, then the value of `repository/online/component/%s` will be used to achieve backward compatibility.
         """
-
         c_prefix = self.ucrv()
         if self.updater.is_repository_server:
             m_url = UcsRepoUrl(self.updater.configRegistry, 'repository/mirror')
@@ -1181,7 +1147,7 @@ class Component(object):
             return self.DISABLED
 
         try:
-            comp_file = open(self.FN_APTSOURCES, 'r')
+            comp_file = open(self.FN_APTSOURCES)
         except IOError:
             return self.UNKNOWN
         rePath = re.compile('(un)?maintained/component/ ?%s/' % self.name)
@@ -1223,9 +1189,7 @@ class Component(object):
 
 
 class UniventionUpdater(object):
-    """
-    Handle UCS package repositories.
-    """
+    """Handle UCS package repositories."""
 
     def __init__(self, check_access=True):
         # type: (bool) -> None
@@ -1245,9 +1209,7 @@ class UniventionUpdater(object):
 
     def config_repository(self):
         # type: () -> None
-        """
-        Retrieve configuration to access repository. Overridden by :py:class:`univention.updater.UniventionMirror`.
-        """
+        """Retrieve configuration to access repository. Overridden by :py:class:`univention.updater.UniventionMirror`."""
         self.online_repository = self.configRegistry.is_true('repository/online', True)
         self.repourl = UcsRepoUrl(self.configRegistry, 'repository/online')
         self.sources = self.configRegistry.is_true('repository/online/sources', False)
@@ -1257,9 +1219,7 @@ class UniventionUpdater(object):
 
     def ucr_reinit(self):
         # type: () -> None
-        """
-        Re-initialize settings.
-        """
+        """Re-initialize settings."""
         self.configRegistry.load()
 
         self.is_repository_server = self.configRegistry.is_true('local/repository', False)
@@ -1304,9 +1264,7 @@ class UniventionUpdater(object):
 
     def _get_releases(self):
         # type: () -> None
-        """
-        Detect server prefix and download `ucs-releases.json` file.
-        """
+        """Detect server prefix and download `ucs-releases.json` file."""
         try:
             if not self.repourl.path:
                 try:
@@ -1350,7 +1308,7 @@ class UniventionUpdater(object):
                     ver = UCS_Version((
                         major_release['major'],
                         minor_release['minor'],
-                        patchlevel_release['patchlevel']
+                        patchlevel_release['patchlevel'],
                     ))
                     if start and ver < start:
                         continue
@@ -1784,9 +1742,7 @@ class UniventionUpdater(object):
 
 
 class LocalUpdater(UniventionUpdater):
-    """
-    Direct file access to local repository.
-    """
+    """Direct file access to local repository."""
 
     def __init__(self):
         # type: () -> None
